# Generated by Django 3.2.12 on 2022-02-13 17:48

import datetime
from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Profile',
            fields=[
                ('oid', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('device_category', models.CharField(max_length=16)),
                ('platform', models.CharField(max_length=16)),
                ('screen_height', models.IntegerField()),
                ('screen_width', models.IntegerField()),
                ('user_agent', models.TextField()),
                ('viewport_height', models.IntegerField()),
                ('viewport_width', models.IntegerField()),
                ('weight', models.DecimalField(decimal_places=24, max_digits=25)),
            ],
            options={
                'db_table': 'djspoofer_profile',
                'ordering': ['-weight'],
            },
        ),
        migrations.CreateModel(
            name='Proxy',
            fields=[
                ('oid', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('url', models.TextField(unique=True)),
                ('mode', models.IntegerField(choices=[(0, 'ROTATING'), (1, 'STICKY'), (2, 'GENERAL')], default=2)),
                ('country', models.CharField(blank=True, max_length=3, null=True)),
                ('city', models.CharField(blank=True, max_length=64, null=True)),
                ('last_used', models.DateTimeField(blank=True, null=True)),
                ('used_ct', models.IntegerField(default=0)),
                ('cooldown', models.DurationField(default=datetime.timedelta(seconds=600))),
            ],
            options={
                'db_table': 'djspoofer_proxy',
                'ordering': ['url'],
            },
        ),
        migrations.AddIndex(
            model_name='profile',
            index=models.Index(fields=['device_category'], name='profile_device_category_index'),
        ),
        migrations.AddIndex(
            model_name='profile',
            index=models.Index(fields=['platform'], name='profile_platform_index'),
        ),
    ]
