# Generated by Django 3.2.12 on 2022-04-08 14:37

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djspoofer', '0013_auto_20220407_2022'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='fingerprint',
            name='proxy',
        ),
    ]
