# Generated by Django 3.2.12 on 2022-04-03 22:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djspoofer', '0007_auto_20220330_2108'),
    ]

    operations = [
        migrations.AddField(
            model_name='tlsfingerprint',
            name='user_agent',
            field=models.TextField(default=''),
            preserve_default=False,
        ),
    ]
