# Generated by Django 3.2.12 on 2022-02-20 17:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djspoofer', '0003_auto_20220220_1504'),
    ]

    operations = [
        migrations.AlterField(
            model_name='proxy',
            name='mode',
            field=models.IntegerField(choices=[(10, 'GENERAL'), (20, 'ROTATING'), (30, 'STICKY')], default=10),
        ),
    ]
