# Generated by Django 3.2.12 on 2022-04-06 00:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djspoofer', '0010_auto_20220404_1546'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='tlsfingerprint',
            name='fingerprint',
        ),
        migrations.RemoveField(
            model_name='fingerprint',
            name='proxy',
        ),
        migrations.AddField(
            model_name='fingerprint',
            name='ciphers',
            field=models.TextField(default=''),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='fingerprint',
            name='extensions',
            field=models.IntegerField(default=1),
            preserve_default=False,
        ),
        migrations.AddIndex(
            model_name='fingerprint',
            index=models.Index(fields=['extensions'], name='fp_extensions_index'),
        ),
        migrations.AddIndex(
            model_name='fingerprint',
            index=models.Index(fields=['ciphers'], name='fp_ciphers_index'),
        ),
        migrations.DeleteModel(
            name='TLSFingerprint',
        ),
    ]
