# Generated by Django 3.2.12 on 2022-02-20 15:04

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('djspoofer', '0002_rename_used_ct_proxy_used_count'),
    ]

    operations = [
        migrations.CreateModel(
            name='Fingerprint',
            fields=[
                ('oid', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('device_category', models.CharField(max_length=16)),
                ('platform', models.CharField(max_length=16)),
                ('screen_height', models.IntegerField()),
                ('screen_width', models.IntegerField()),
                ('user_agent', models.TextField()),
                ('viewport_height', models.IntegerField()),
                ('viewport_width', models.IntegerField()),
                ('proxy', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='fingerprints', to='djspoofer.proxy')),
            ],
            options={
                'db_table': 'djspoofer_fingerprint',
                'ordering': ['-created'],
            },
        ),
        migrations.DeleteModel(
            name='Profile',
        ),
        migrations.AddIndex(
            model_name='fingerprint',
            index=models.Index(fields=['device_category'], name='fp_device_category_index'),
        ),
        migrations.AddIndex(
            model_name='fingerprint',
            index=models.Index(fields=['platform'], name='fp_platform_index'),
        ),
    ]
