# Generated by Django 3.2.12 on 2022-04-07 20:22

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('djspoofer', '0012_fingerprint_proxy'),
    ]

    operations = [
        migrations.CreateModel(
            name='TLSFingerprint',
            fields=[
                ('oid', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('browser', models.CharField(max_length=32)),
                ('extensions', models.IntegerField()),
                ('ciphers', models.TextField()),
            ],
            options={
                'db_table': 'djspoofer_tls_fingerprint',
                'ordering': ['-created'],
            },
        ),
        migrations.RemoveIndex(
            model_name='fingerprint',
            name='fp_extensions_index',
        ),
        migrations.RemoveIndex(
            model_name='fingerprint',
            name='fp_ciphers_index',
        ),
        migrations.RemoveField(
            model_name='fingerprint',
            name='ciphers',
        ),
        migrations.RemoveField(
            model_name='fingerprint',
            name='extensions',
        ),
        migrations.AddIndex(
            model_name='fingerprint',
            index=models.Index(fields=['browser'], name='fp_browser_index'),
        ),
        migrations.AddIndex(
            model_name='tlsfingerprint',
            index=models.Index(fields=['browser'], name='tls_fp_browser_index'),
        ),
        migrations.AddField(
            model_name='fingerprint',
            name='tls_fingerprint',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='fingerprints', to='djspoofer.tlsfingerprint'),
        ),
    ]
