# Generated by Django 3.2.12 on 2022-04-03 22:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djspoofer', '0008_tlsfingerprint_user_agent'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='tlsfingerprint',
            name='user_agent',
        ),
    ]
