# Generated by Django 3.2.12 on 2022-04-06 00:39

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djspoofer', '0011_auto_20220406_0036'),
    ]

    operations = [
        migrations.AddField(
            model_name='fingerprint',
            name='proxy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='fingerprints', to='djspoofer.proxy'),
        ),
    ]
